@@ -6,5 +6,5 @@ dir_ = '/usr/pkg/share/glib-2.0/gdb'
 if not dir_ in sys.path:
     sys.path.insert(0, dir_)
 
-from gobject import register
+from gobject_gdb import register
 register (gdb.current_objfile ())
